==> aroundme_0_5_1.zip: aroundme_0_5_1/aroundme/language/1/barnraiser_01/frm_list.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
//
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

require_once($languagePath . 'g_common.lang.php');

/*
* All language vars should be ordered TYPE, A-Z for convenience
* Tom Calthrop - 20th April 2004 (tom@barnraiser.org)
*/


//HEADER
$lang['hdr_topics'] = 							"topics";
$lang['section_forum'] = 						"latest discussions";


// HREF
$lang['href_edit_topics'] = 					"edit topics";
$lang['href_add_subject'] = 					"add subject";
$lang['href_see_all_sub'] = 					"see all subjects";
$lang['menu_latest_discussions'] = 				"latest";


//BODY TEXT
$lang['txt_forum'] = 							"discussions";//breadcrumb
$lang['txt_total_subjects'] = 					"total subjects";//??
$lang['txt_search_discussions'] = 				"search for discussions";
$lang['txt_subject_datetime'] = 				"subject date and time";
$lang['txt_comment_total'] = 					"total comments";
$lang['txt_movement'] = 						"movement";
$lang['txt_lastview'] = 						"last viewed";
$lang['txt_watching'] = 						"marked";
$lang['txt_last_comment'] = 					"last comment";



?>

==> aroundme_0_5_2.zip: aroundme_0_5_2/aroundme/language/1/barnraiser_01/frm_list.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
//
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

require_once($languagePath . 'g_common.lang.php');

/*
* All language vars should be ordered TYPE, A-Z for convenience
* Tom Calthrop - 20th April 2004 (tom@barnraiser.org)
*/


//HEADER
$lang['hdr_topics'] = 							"topics";
$lang['section_forum'] = 						"latest discussions";


// HREF
$lang['href_edit_topics'] = 					"edit topics";
$lang['href_add_subject'] = 					"add subject";
$lang['href_see_all_sub'] = 					"go to topic";
$lang['menu_latest_discussions'] = 				"latest";


//BODY TEXT
$lang['txt_forum'] = 							"discussions";//breadcrumb
$lang['txt_total_subjects'] = 					"total subjects";//??
$lang['txt_search_discussions'] = 				"search for discussions";
$lang['txt_subject_datetime'] = 				"subject date and time";
$lang['txt_comment_total'] = 					"total comments";
$lang['txt_movement'] = 						"movement";
$lang['txt_lastview'] = 						"last viewed";
$lang['txt_watching'] = 						"marked";
$lang['txt_last_comment'] = 					"last comment";
$lang['txt_topic_role_add'] = 					"The following roles can add subjects to this topic";

?>
